==> nextcloud-13.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/gallery/l10n/lv.js <==
OC.L10N.register(
    "gallery",
    {
    "Gallery" : "Galerija",
    "There was a problem reading files from this album" : "Radās problēma nolasot failus no šī albuma",
    "Aborting preview. Could not find the file" : "Pārtrauc priekšskatījumu. Nevarēja atrast failu",
    "Could not move \"{file}\", target exists" : "Nevarēja pārvietot \"{file}\", mērķis eksistē",
    "Could not move \"{file}\"" : "Nevar pārvietot \"{file}\"",
    "No compatible server found at {remote}" : "Nav atrasts neviens saderīgs serveris {remote}",
    "Invalid server url" : "Nederīgs servera url",
    "Could not load the description" : "Nevarēja ielādēt aprakstu",
    "Could not load the description: " : "Nevarēja ielādēt aprakstu:",
    "Copyright" : "Autortiesības",
    "Could not load the copyright notice: " : "Nevarēja ielādēt autortiesību paziņojumu:",
    "Copyright notice" : "Autortiesību paziņojums",
    "Link to copyright document" : "Saite uz autortiesību dokumentiem",
    "This application may not work properly on your browser." : "Iespējams, šī lietojumprogramma nedarbojas pareizi, jūsu pārlūkprogrammā.",
    "For an improved experience, please install one of the following alternatives" : "Lai uzlabotu pieredzi, lūdzu, instalējiet vienu no šādām alternatīvām",
    "Your browser is not supported!" : "Jūsu pārlūkprogramma netiek atbalstīta!",
    "please install one of the following alternatives" : "lūdzu, instalējiet kādu no peejamām alternatīvām",
    "Album cannot be shown" : "Albumu nevar parādīt",
    "No media files found" : "Nav atrasts neviens multivides fails",
    "Configuration error" : "Konfigurācijas kļūda",
    "New" : "Jauna",
    "Hide Album" : "Slēpt Albūmu",
    "Could not hide album" : "Nevarēja paslēpt albumu",
    "Error loading slideshow template" : "Kļūda ielādējot slīdrādes veidolu",
    "<strong>Error!</strong> Could not generate a preview of this file.<br>Please go to the next slide while we remove this image from the slideshow" : "<strong>Kļūda!</strong> Nevarēja izveidot faila priekšskatījumu.<br>Lūdzu, pārejiet uz nākamo slaidu, kamēr mēs noņemt šo attēlu no slaidrādes",
    "Next" : "Nākamā",
    "Play" : "Atskaņot",
    "Pause" : "Pauzēt",
    "Previous" : "Iepriekšējā",
    "Close" : "Aizvērt",
    "Download" : "Lejupielādēt",
    "Toggle background" : "Ieslēgt fonu",
    "Delete" : "Dzēst",
    "Share" : "Koplietot",
    "Could not create file \"{file}\" because it already exists" : "Nevarēja izveidot datni \"{file}\", jo tā jau eksistē",
    "Could not create file \"{file}\"" : "Nevarēja izveidot datni \"{file}\"",
    "\"{name}\" is an invalid file name." : "\"{name}\" ir nepareizs datnes nosaukums.",
    "File name cannot be empty." : "Datnes nosaukums nevar būt tukšs.",
    "Upload" : "Augšupielādēt",
    "Error" : "Kļūda",
    "Error while sharing" : "Kļūda, daloties",
    "Error while unsharing" : "Kļūda, beidzot dalīties",
    "Error while changing permissions" : "Kļūda, mainot atļaujas",
    "Shared with you and the group {group} by {owner}" : "{owner} dalījās ar jums un grupu {group}",
    "Shared with you by {owner}" : "{owner} dalījās ar jums",
    "Share with users or groups …" : "Koplietot ar lietotājiem vai grupām ...",
    "Share link" : "Koplietot saiti",
    "Link" : "Saite",
    "Password protect" : "Aizsargāt ar paroli",
    "Password" : "Parole",
    "Choose a password for the public link" : "Izvēlies paroli publiskai saitei",
    "Allow editing" : "Atļaut rediģēt",
    "Email link to person" : "Sūtīt saiti personai pa e-pastu",
    "Send" : "Sūtīt",
    "Set expiration date" : "Iestaties termiņa datumu",
    "Expiration" : "Termiņš",
    "Expiration date" : "Termiņa datums",
    "An error occured. Please try again" : "Notika kļūda. Mēģini vēlreiz.",
    "Adding user..." : "Lietotāja pievienošana...",
    "group" : "grupa",
    "remote" : "attālināti",
    "Resharing is not allowed" : "Atkārtota dalīšanās nav atļauta",
    "Unshare" : "Pārtraukt dalīšanos",
    "notify by email" : "ziņot e-pastā",
    "can share" : "Var dalīties",
    "can edit" : "var rediģēt",
    "access control" : "piekļuves vadība",
    "create" : "izveidot",
    "change" : "mainīt",
    "delete" : "dzēst",
    "Password protected" : "Aizsargāts ar paroli",
    "Error unsetting expiration date" : "Kļūda, noņemot termiņa datumu",
    "Error setting expiration date" : "Kļūda, iestatot termiņa datumu",
    "Sending ..." : "Sūta...",
    "Email sent" : "Vēstule nosūtīta",
    "Warning" : "Brīdinājums",
    "This share is password-protected" : "Šī koplietotne ir aizsargāta ar paroli",
    "The password is wrong. Try again." : "Nepareiza parole. Mēģiniet vēlreiz.",
    "Sort by name" : "Kārtot pēc nosaukuma",
    "Sort by date" : "Kārtot pēc datuma",
    "Cancel upload" : "Atcelt augšupielādi",
    "Album information" : "Albūma informācija",
    "File list" : "Failu saraksts",
    "Sorry, this file could not be found." : "Atvainojiet, šo failu nevar atrast.",
    "Reasons might be:" : "Iespējamie iemesli:",
    "the file was removed" : "šis fails ir noņemts",
    "the file is corrupt" : "šis fails ir bojāts",
    "For more information, please contact your friendly Nextcloud administrator." : "Plašākai informācijai, lūdzu, sazinieties ar draudzīgo administratoru.",
    "Sorry, but the server could not fulfill your request." : "Atvainojiet, bet serveris nevar izpildīt jūsu pieprasījumu.",
    "Possible reasons for the problem:" : "Iespējamo problēmu iemesls:",
    "Sorry, this link doesn't seem to work anymore." : "Izskatās, ka šī saite vairs nedarbojas",
    "the item was removed" : "vienums tika dzēsts",
    "the link has expired" : "saites derīgums ir beidzies",
    "sharing is disabled" : "koplietošana nav ieslēgta",
    "For more information, please ask the person who has sent you this link." : "Vairāk informācijas vaicā personai, kas nosūtīja šo saiti.",
    "Add to your Nextcloud" : "Pievienot savam Nextcloud",
    "Picture view" : "Attēla skats",
    "Gallery view" : "Galerijas skats"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");

==> nextcloud-13.0.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/gallery/l10n/lv.js <==
OC.L10N.register(
    "gallery",
    {
    "Gallery" : "Galerija",
    "There was a problem reading files from this album" : "Radās problēma nolasot datnes no šī albuma",
    "Aborting preview. Could not find the file" : "Pārtrauc priekšskatījumu. Nevarēja atrast datni",
    "Could not move \"{file}\", target exists" : "Nevarēja pārvietot \"{file}\", mērķis eksistē",
    "Could not move \"{file}\"" : "Nevar pārvietot \"{file}\"",
    "No compatible server found at {remote}" : "Nav atrasts neviens saderīgs serveris {remote}",
    "Invalid server url" : "Nederīgs servera url",
    "Could not load the description" : "Nevarēja ielādēt aprakstu",
    "Could not load the description: " : "Nevarēja ielādēt aprakstu:",
    "Copyright" : "Autortiesības",
    "Could not load the copyright notice: " : "Nevarēja ielādēt autortiesību paziņojumu:",
    "Copyright notice" : "Autortiesību paziņojums",
    "Link to copyright document" : "Saite uz autortiesību dokumentiem",
    "This application may not work properly on your browser." : "Iespējams, šī lietojumprogramma nedarbojas pareizi, jūsu pārlūkprogrammā.",
    "For an improved experience, please install one of the following alternatives" : "Lai uzlabotu pieredzi, lūdzu, instalējiet vienu no šādām alternatīvām",
    "Your browser is not supported!" : "Jūsu pārlūkprogramma netiek atbalstīta!",
    "please install one of the following alternatives" : "lūdzu, instalējiet kādu no peejamām alternatīvām",
    "Album cannot be shown" : "Albumu nevar parādīt",
    "No media files found" : "Nav atrasta neviena multivides datne",
    "Configuration error" : "Konfigurācijas kļūda",
    "New" : "Jauna",
    "Hide Album" : "Slēpt Albūmu",
    "Could not hide album" : "Nevarēja paslēpt albumu",
    "Error loading slideshow template" : "Kļūda ielādējot slīdrādes veidolu",
    "<strong>Error!</strong> Could not generate a preview of this file.<br>Please go to the next slide while we remove this image from the slideshow" : "<strong>Kļūda!</strong> Nevarēja izveidot datnes priekšskatījumu.<br>Lūdzu, pārejiet uz nākamo slaidu, kamēr mēs noņemam šo attēlu no slaidrādes",
    "Next" : "Nākamā",
    "Play" : "Atskaņot",
    "Pause" : "Pauzēt",
    "Previous" : "Iepriekšējā",
    "Close" : "Aizvērt",
    "Download" : "Lejupielādēt",
    "Toggle background" : "Ieslēgt fonu",
    "Delete" : "Dzēst",
    "Share" : "Koplietot",
    "Could not create file \"{file}\" because it already exists" : "Nevarēja izveidot datni \"{file}\", jo tā jau eksistē",
    "Could not create file \"{file}\"" : "Nevarēja izveidot datni \"{file}\"",
    "\"{name}\" is an invalid file name." : "\"{name}\" ir nepareizs datnes nosaukums.",
    "File name cannot be empty." : "Datnes nosaukums nevar būt tukšs.",
    "Upload" : "Augšupielādēt",
    "Error" : "Kļūda",
    "Error while sharing" : "Kļūda, daloties",
    "Error while unsharing" : "Kļūda, beidzot dalīties",
    "Error while changing permissions" : "Kļūda, mainot atļaujas",
    "Shared with you and the group {group} by {owner}" : "{owner} dalījās ar jums un grupu {group}",
    "Shared with you by {owner}" : "{owner} dalījās ar jums",
    "Share with users or groups …" : "Koplietot ar lietotājiem vai grupām ...",
    "Share link" : "Koplietot saiti",
    "Link" : "Saite",
    "Password protect" : "Aizsargāt ar paroli",
    "Password" : "Parole",
    "Choose a password for the public link" : "Izvēlies paroli publiskai saitei",
    "Allow editing" : "Atļaut rediģēt",
    "Email link to person" : "Sūtīt saiti personai pa e-pastu",
    "Send" : "Sūtīt",
    "Set expiration date" : "Iestaties termiņa datumu",
    "Expiration" : "Termiņš",
    "Expiration date" : "Termiņa datums",
    "Adding user..." : "Lietotāja pievienošana...",
    "group" : "grupa",
    "remote" : "attālināti",
    "Resharing is not allowed" : "Atkārtota dalīšanās nav atļauta",
    "Unshare" : "Pārtraukt dalīšanos",
    "notify by email" : "ziņot e-pastā",
    "can share" : "Var dalīties",
    "can edit" : "var rediģēt",
    "access control" : "piekļuves vadība",
    "create" : "izveidot",
    "change" : "mainīt",
    "delete" : "dzēst",
    "Password protected" : "Aizsargāts ar paroli",
    "Error unsetting expiration date" : "Kļūda, noņemot termiņa datumu",
    "Error setting expiration date" : "Kļūda, iestatot termiņa datumu",
    "Sending…" : "Sūta …",
    "Email sent" : "Vēstule nosūtīta",
    "Warning" : "Brīdinājums",
    "shared by %s" : "Koplietoja %s",
    "Add to your Nextcloud" : "Pievienot savam Nextcloud",
    "This share is password-protected" : "Šī koplietotne ir aizsargāta ar paroli",
    "The password is wrong. Try again." : "Nepareiza parole. Mēģiniet vēlreiz.",
    "Sort by name" : "Kārtot pēc nosaukuma",
    "Sort by date" : "Kārtot pēc datuma",
    "Cancel upload" : "Atcelt augšupielādi",
    "Album information" : "Albūma informācija",
    "File list" : "Failu saraksts",
    "Sorry, this file could not be found." : "Atvainojiet, šo failu nevar atrast.",
    "Reasons might be:" : "Iespējamie iemesli:",
    "the wrong file ID was provided" : "Iedots nepareizs datnes ID",
    "the file was removed" : "šis fails ir noņemts",
    "the file is corrupt" : "šis fails ir bojāts",
    "the encryption key is missing" : "šifrēšanas atslēga ir pazudusi",
    "For more information, please contact your friendly Nextcloud administrator." : "Plašākai informācijai, lūdzu, sazinieties ar draudzīgo administratoru.",
    "Sorry, but the server could not fulfill your request." : "Atvainojiet, bet serveris nevar izpildīt jūsu pieprasījumu.",
    "Possible reasons for the problem:" : "Iespējamo problēmu iemesls:",
    "a conflicting app was installed" : "konfilktējoša lietotne bija instalēta",
    "the filesystem is not readable" : "datņu sistēma nav lasāma",
    "Sorry, this link doesn't seem to work anymore." : "Izskatās, ka šī saite vairs nedarbojas",
    "the item was removed" : "vienums tika dzēsts",
    "the link has expired" : "saites derīgums ir beidzies",
    "sharing is disabled" : "koplietošana nav ieslēgta",
    "For more information, please ask the person who has sent you this link." : "Vairāk informācijas vaicā personai, kas nosūtīja šo saiti.",
    "Picture view" : "Attēla skats",
    "Gallery view" : "Galerijas skats",
    "An error occured. Please try again" : "Notika kļūda. Mēģini vēlreiz.",
    "Sending ..." : "Sūta..."
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
